Author: Made by 'tree'

# Directory Tree

.
├── 02.txt
├── 03.txt
├── 04.txt
├── 05.txt
├── 06.txt
├── 07.txt
├── 08.txt
├── 09.txt
├── 10.txt
├── 11.txt
├── 12.txt
├── 13.txt
├── 14.txt
├── 15.txt
├── 16.txt
├── 17.txt
├── 18.txt
├── 19.txt
├── 20.txt
├── 21.txt
├── 22.txt
├── 23.txt
├── 24.rst
├── 25.rst
└── index.html

0 directories, 25 files

tree -H . -o index.html

tree v1.8.0 © 1996 - 2018 by Steve Baker and Thomas Moore
HTML output hacked and copyleft © 1998 by Francesc Rocher
JSON output hacked and copyleft © 2014 by Florian Sesser
Charsets / OS/2 support © 2001 by Kyosuke Tokoro